@@ -1,7 +1,5 @@
 # _*_ coding: utf-8 _*_
-from zope.interface import Attribute
-from zope.interface import Interface
-
+from zope.interface import Attribute, Interface
 
 __author__ = "Md Nazrul Islam<email2nazrul@gmail.com>"
 
