@@ -1,10 +1,8 @@
 # _*_ coding: utf-8 _*_
-from zope.interface import Attribute
-from zope.interface import Interface
+from zope.interface import Attribute, Interface
 
 from .base import IBaseClass
 
-
 __author__ = "Md Nazrul Islam<email2nazrul@gmail.com>"
 
 
