@@ -6,6 +6,7 @@ import os
 import pkgutil
 import re
 import sys
+import time
 import uuid
 from importlib import import_module
 from inspect import signature
@@ -13,7 +14,6 @@ from types import ModuleType
 from typing import (
     TYPE_CHECKING,
     Any,
-    Callable,
     Dict,
     List,
     Match,
@@ -25,9 +25,7 @@ from typing import (
     cast,
 )
 
-import orjson
 import pkg_resources
-from pydantic.json import pydantic_encoder
 from pydantic.validators import bool_validator
 from yarl import URL
 from zope.interface import implementer
@@ -36,6 +34,7 @@ from fhirpath.thirdparty import Proxy
 
 from .enums import FHIR_VERSION
 from .interfaces import IPathInfoContext
+from .json import json_dumps, json_loads  # noqa: F401
 from .storage import FHIR_RESOURCE_CLASS_STORAGE, PATH_INFO_STORAGE
 from .types import PrimitiveDataTypes
 
@@ -52,6 +51,8 @@ if TYPE_CHECKING:
 
 __author__ = "Md Nazrul Islam <email2nazrul@gmail.com>"
 
+LOCAL_TIMEZONE: Optional[datetime.timezone] = None
+
 
 def _reraise(tp, value, tb=None):
     if value is None:
@@ -531,15 +532,21 @@ class BundleWrapper:
     """ """
 
     def __init__(
-        self, engine, result, includes: List, url: URL, bundle_type="searchset"
+        self,
+        engine,
+        result,
+        includes: List,
+        url: URL,
+        bundle_type="searchset",
+        init_data: Dict[str, Any] = None,
     ):
         """ """
         self.fhir_version = engine.fhir_release
         self.bundle_model = lookup_fhir_class("Bundle", fhir_release=self.fhir_version)
-        self.data: Dict[str, Any] = dict()
-        self.data["id"] = str(uuid.uuid4())
-
-        self.data["meta"] = {"lastUpdated": datetime.datetime.utcnow()}
+        if init_data:
+            self.data = init_data
+        else:
+            self.data = BundleWrapper.init_data()
 
         self.data["type"] = bundle_type
         # our pagination is based main query result.
@@ -555,6 +562,12 @@ class BundleWrapper:
 
         self.attach_links(url, len(result.body))
 
+    @staticmethod
+    def init_data() -> Dict[str, Any]:
+        """Initialized Bundle data"""
+        data = {"id": str(uuid.uuid4()), "meta": {"lastUpdated": timestamp_utc()}}
+        return data
+
     def attach_entry(self, result, mode="match"):
         """ """
         if "entry" not in self.data:
@@ -657,44 +670,23 @@ class BundleWrapper:
         return self.__call__().json()
 
 
-def json_dumps(
-    value: Union[List[Dict[str, Any]], Dict[str, Any]],
-    *,
-    default: Callable = None,
-    option: int = 0,
-    indent: int = None,
-    sort_keys: bool = None,
-    return_bytes: bool = False,
-) -> Union[str, bytes]:
-    """Special helper function to serialize to json str, powered by ``orjson``"""
-    if default is None:
-        default = pydantic_encoder
+def get_local_timezone() -> datetime.timezone:
+    if LOCAL_TIMEZONE is not None:
+        return LOCAL_TIMEZONE
 
-    params: Any = {"default": default}
-    option_ = option
-    if option_ == 0:
-        if indent is not None:
-            # only indent 2 is accepted
-            option_ |= orjson.OPT_INDENT_2
-        if sort_keys is not None and sort_keys:
-            option_ |= orjson.OPT_SORT_KEYS
-
-    if option_ > 0:
-        params.update({"option": option_})
-
-    v = orjson.dumps(value, **params)
-    if return_bytes is False:
-        return force_str(v)
-    return v
+    is_dst = time.daylight and time.localtime().tm_isdst > 0
+    seconds = -(time.altzone if is_dst else time.timezone)
+    tz = datetime.timezone(datetime.timedelta(seconds=seconds))
+    return tz
 
 
-def json_loads(
-    value: Union[bytes, bytearray, str]
-) -> Union[List[Dict[str, Any]], Dict[str, Any]]:
-    """bytes, bytearray, and str input are accepted.
-    If the input exists as bytes (was read directly from a source),
-    it is recommended to pass bytes. This has lower memory usage and lower latency.
+def timestamp_utc() -> datetime.datetime:
+    """UTC datetime with timezone offset"""
+    dt_now = datetime.datetime.utcnow()
+    dt_now.replace(tzinfo=datetime.timezone.utc)
+    return dt_now
 
-    The input must be valid UTF-8."""
 
-    return orjson.loads(value)
+def timestamp_local() -> datetime.datetime:
+    """Timezone aware datetime with local timezone offset"""
+    return datetime.datetime.now(tz=get_local_timezone())
